SocketConfigBuilder

Struct SocketConfigBuilder 

pub struct SocketConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> SocketConfigBuilder<S>

pub fn build(self) -> SocketConfig
where S: IsComplete,

Finish building and return the requested object

pub fn url(self, value: String) -> SocketConfigBuilder<SetUrl<S>>
where S::Url: IsUnset,

Required.

The URL to connect to.

pub fn mode(self, value: Mode) -> SocketConfigBuilder<SetMode<S>>
where S::Mode: IsUnset,

Required.

The connection mode {Plain, TLS}.

pub fn suffix(self, value: Vec<u8>) -> SocketConfigBuilder<SetSuffix<S>>
where S::Suffix: IsUnset,

Required.

The sequence of bytes which separates lines.

pub fn message_handler( self, value: TcpMessageHandler, ) -> SocketConfigBuilder<SetMessageHandler<S>>
where S::MessageHandler: IsUnset,

Optional (Some / Option setters). The optional function to handle incoming messages.

pub fn maybe_message_handler( self, value: Option<TcpMessageHandler>, ) -> SocketConfigBuilder<SetMessageHandler<S>>
where S::MessageHandler: IsUnset,

Optional (Some / Option setters). The optional function to handle incoming messages.

pub fn heartbeat( self, value: (u64, Vec<u8>), ) -> SocketConfigBuilder<SetHeartbeat<S>>
where S::Heartbeat: IsUnset,

Optional (Some / Option setters). The optional heartbeat with period and beat message.

pub fn maybe_heartbeat( self, value: Option<(u64, Vec<u8>)>, ) -> SocketConfigBuilder<SetHeartbeat<S>>
where S::Heartbeat: IsUnset,

Optional (Some / Option setters). The optional heartbeat with period and beat message.

pub fn reconnect_timeout_ms( self, value: u64, ) -> SocketConfigBuilder<SetReconnectTimeoutMs<S>>
where S::ReconnectTimeoutMs: IsUnset,

Optional (Some / Option setters). The timeout (milliseconds) for reconnection attempts.

pub fn maybe_reconnect_timeout_ms( self, value: Option<u64>, ) -> SocketConfigBuilder<SetReconnectTimeoutMs<S>>
where S::ReconnectTimeoutMs: IsUnset,

Optional (Some / Option setters). The timeout (milliseconds) for reconnection attempts.

pub fn reconnect_delay_initial_ms( self, value: u64, ) -> SocketConfigBuilder<SetReconnectDelayInitialMs<S>>
where S::ReconnectDelayInitialMs: IsUnset,

Optional (Some / Option setters). The initial reconnection delay (milliseconds) for reconnects.

pub fn maybe_reconnect_delay_initial_ms( self, value: Option<u64>, ) -> SocketConfigBuilder<SetReconnectDelayInitialMs<S>>
where S::ReconnectDelayInitialMs: IsUnset,

Optional (Some / Option setters). The initial reconnection delay (milliseconds) for reconnects.

pub fn reconnect_delay_max_ms( self, value: u64, ) -> SocketConfigBuilder<SetReconnectDelayMaxMs<S>>
where S::ReconnectDelayMaxMs: IsUnset,

Optional (Some / Option setters). The maximum reconnect delay (milliseconds) for exponential backoff.

pub fn maybe_reconnect_delay_max_ms( self, value: Option<u64>, ) -> SocketConfigBuilder<SetReconnectDelayMaxMs<S>>
where S::ReconnectDelayMaxMs: IsUnset,

Optional (Some / Option setters). The maximum reconnect delay (milliseconds) for exponential backoff.

pub fn reconnect_backoff_factor( self, value: f64, ) -> SocketConfigBuilder<SetReconnectBackoffFactor<S>>
where S::ReconnectBackoffFactor: IsUnset,

Optional (Some / Option setters). The exponential backoff factor for reconnection delays.

pub fn maybe_reconnect_backoff_factor( self, value: Option<f64>, ) -> SocketConfigBuilder<SetReconnectBackoffFactor<S>>
where S::ReconnectBackoffFactor: IsUnset,

Optional (Some / Option setters). The exponential backoff factor for reconnection delays.

pub fn reconnect_jitter_ms( self, value: u64, ) -> SocketConfigBuilder<SetReconnectJitterMs<S>>
where S::ReconnectJitterMs: IsUnset,

Optional (Some / Option setters). The maximum jitter (milliseconds) added to reconnection delays.

pub fn maybe_reconnect_jitter_ms( self, value: Option<u64>, ) -> SocketConfigBuilder<SetReconnectJitterMs<S>>
where S::ReconnectJitterMs: IsUnset,

Optional (Some / Option setters). The maximum jitter (milliseconds) added to reconnection delays.

pub fn connection_max_retries( self, value: u32, ) -> SocketConfigBuilder<SetConnectionMaxRetries<S>>
where S::ConnectionMaxRetries: IsUnset,

Optional (Some / Option setters). The maximum number of initial connection attempts (default: 5).

pub fn maybe_connection_max_retries( self, value: Option<u32>, ) -> SocketConfigBuilder<SetConnectionMaxRetries<S>>
where S::ConnectionMaxRetries: IsUnset,

Optional (Some / Option setters). The maximum number of initial connection attempts (default: 5).

pub fn reconnect_max_attempts( self, value: u32, ) -> SocketConfigBuilder<SetReconnectMaxAttempts<S>>
where S::ReconnectMaxAttempts: IsUnset,

Optional (Some / Option setters). The maximum number of reconnection attempts before giving up.

  • None: Unlimited reconnection attempts (default, recommended for production).
  • Some(n): After n failed attempts, transition to CLOSED state.
pub fn maybe_reconnect_max_attempts( self, value: Option<u32>, ) -> SocketConfigBuilder<SetReconnectMaxAttempts<S>>
where S::ReconnectMaxAttempts: IsUnset,

Optional (Some / Option setters). The maximum number of reconnection attempts before giving up.

  • None: Unlimited reconnection attempts (default, recommended for production).
  • Some(n): After n failed attempts, transition to CLOSED state.
pub fn idle_timeout_ms( self, value: u64, ) -> SocketConfigBuilder<SetIdleTimeoutMs<S>>
where S::IdleTimeoutMs: IsUnset,

Optional (Some / Option setters). The idle timeout (milliseconds) for the read task. When set, the read task will break and trigger reconnection if no data is received within this duration. Useful for detecting silently dead connections where the server stops sending without closing.

pub fn maybe_idle_timeout_ms( self, value: Option<u64>, ) -> SocketConfigBuilder<SetIdleTimeoutMs<S>>
where S::IdleTimeoutMs: IsUnset,

Optional (Some / Option setters). The idle timeout (milliseconds) for the read task. When set, the read task will break and trigger reconnection if no data is received within this duration. Useful for detecting silently dead connections where the server stops sending without closing.

pub fn certs_dir(self, value: String) -> SocketConfigBuilder<SetCertsDir<S>>
where S::CertsDir: IsUnset,

Optional (Some / Option setters). The path to the certificates directory.

pub fn maybe_certs_dir( self, value: Option<String>, ) -> SocketConfigBuilder<SetCertsDir<S>>
where S::CertsDir: IsUnset,

Optional (Some / Option setters). The path to the certificates directory.